.. _api-core-exceptions:

==========
Exceptions
==========

.. automodule:: projector.core.exceptions

Return to :ref:`api-core`.

.. error:: ProjectorError

ProjectorError
==============

.. autoclass:: projector.core.exceptions.ProjectorError


.. error:: ConfigAlreadyExist

ConfigAlreadyExist
==================

.. autoclass:: projector.core.exceptions.ConfigAlreadyExist

.. error:: ForkError

ForkError
=========

.. autoclass:: projector.core.exceptions.ForkError

